//NBglass demo file for povray 2.x

/*
The Glass and Glass2 textures supplied in textures.inc
work OK for spheres, but render too dark when applied
to angular objects.  This file introduces a new texture,
NBglass, which delivers consistent tonal values when
applied to a variety of shapes.  Also demonstrates 3
derived textures: NBoldglass, NBwinebottle, and 
NBbeerbottle.

New textures are in front row.  Textures.inc textures
Glass, Glass2, Glass3, and Green_Glass in back row.

Enjoy.  Norm Bowler, Richland WA
*/

//may want to increase max_trace_level if you
//get display artifacts.


//setup
#include "colors.inc"
#include "textures.inc"

camera {
   location   <0, 4,-4>
   direction  <0, 0, 1.75>
   up         <0, 1, 0>
   right      <4/3, 0, 0>
   look_at    <0,.75,0>
}

light_source {<0, 30, -10> color White}

default {
  finish {ambient .2 diffuse .8}
}

background {color White}

// ground plane 
plane { y, 0
  pigment {color Gray60}
}

//test object -- take yr pick
#declare TestObj=

/*
sphere {<0,0,0>, .25
  translate <0,.25,0>
}
*/

box {
  <-.25,0,0>,
  <.25,.75,.25>
}

/*
cylinder {
  <0,0,0>, 
  <0,.75,0>, .25
}
*/


//textures.inc textures -- back row

object { TestObj
  texture {Glass}
  translate <-1.5,0,1.5>
}

object { TestObj
  texture {Glass2}
  translate <-.5,0,1.5>
}

object { TestObj
  texture {Glass3}
  translate <.5,0,1.5>
}

object { TestObj
  texture {Green_Glass}
  translate <1.5,0,1.5>
}

//norm's textures -- front row

#declare NBglass=
  texture {
    pigment {color green 1 blue .99 red .98 filter .75}
    finish{
      ambient 0.1
      diffuse 0.1
      reflection .25
      refraction 1
      ior 1.5
      specular 1
      roughness .001
    }
  }

#declare NBoldglass=
  texture { NBglass
    pigment {color green .9 blue .85 red .8 filter .85}
  }

#declare NBwinebottle=
  texture { NBglass
    pigment {color red .4 green .72 blue .4 filter .6}
  }

#declare NBbeerbottle=
  texture { NBglass
    pigment {color red .7 green .5 blue .1 filter .6}
  }

//glass
object { TestObj
  translate <-1.5,0,0>
  texture { NBglass
  }
}

//old glass
object { TestObj
  translate <-.5,0,0>
  texture { NBoldglass}
}

//wine bottle
object { TestObj
  texture { NBwinebottle}
  translate <.5,0,0>
}

//beer bottle
object { TestObj
  texture { NBbeerbottle}
  translate <1.5,0,0>
}

